==> Coin-2.4.4.tar.gz: Coin-2.4.4/src/fonts/defaultfonts.h <==
#ifndef COIN_DEFAULTFONTS_H
#define COIN_DEFAULTFONTS_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2005 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See <URL:http://www.coin3d.org/> for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  <URL:http://www.sim.no/>.
 *
\**************************************************************************/

#ifndef COIN_INTERNAL
#error this is a private header file
#endif /* !COIN_INTERNAL */

#include <Inventor/system/inttypes.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

int coin_default2dfont_get_height(float size);
int coin_default2dfont_get_width(float size);
const unsigned char * coin_default2dfont_get_data(float size);

const float ** coin_default3dfont_get_coords(void);
const int ** coin_default3dfont_get_faceidx(void);
const int ** coin_default3dfont_get_edgeidx(void);
float coin_default3dfont_get_advance(int charidx);

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif /* COIN_DEFAULTSFONTS_H */

==> Coin-2.4.5.tar.gz: Coin-2.4.5/src/fonts/defaultfonts.h <==
#ifndef COIN_DEFAULTFONTS_H
#define COIN_DEFAULTFONTS_H

/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2006 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#ifndef COIN_INTERNAL
#error this is a private header file
#endif /* ! COIN_INTERNAL */

/* ********************************************************************** */

#include <Inventor/system/inttypes.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

int coin_default2dfont_get_height(float size);
int coin_default2dfont_get_width(float size);
const unsigned char * coin_default2dfont_get_data(float size);

const float ** coin_default3dfont_get_coords(void);
const int ** coin_default3dfont_get_faceidx(void);
const int ** coin_default3dfont_get_edgeidx(void);
float coin_default3dfont_get_advance(int charidx);

#ifdef __cplusplus
} /* extern "C" */
#endif /* __cplusplus */

#endif /* COIN_DEFAULTSFONTS_H */
